@@ -1,5 +1,5 @@
 import inspect
-from typing import Any, AsyncGenerator, Callable, Generator, List, Optional, Type, Union, Dict
+from typing import Any, AsyncGenerator, Callable, Generator, List, Optional, Type, Union, _GenericAlias
 
 from iterwrapper import IterWrapper
 
@@ -12,9 +12,14 @@ from ..utilles import async_enumerate, flat_yield_from, is_asyncgener
 
 
 class ContextStackItem:
-  def __init__(self, name, annotation, default, local_dispatchers, index=0) -> None:
+  def __init__(self, name, annotation, default, local_dispatchers, optional=False, index=0) -> None:
     self.name, self.annotation, self.default, self.local_dispatchers, self.index = \
       name, annotation, default, local_dispatchers, index
+    self.optional = optional
+    self.always_dispatchers = []
+    for i in local_dispatchers:
+      if isinstance(i, BaseDispatcher) and i.always:
+        self.always_dispatchers.append(i)
   
   def __repr__(self) -> str:
     return "<ContextStackItem name={0} annotation={1} default={2} locald={3} index={4}>"\
@@ -25,8 +30,12 @@ class ContextStackItem:
   annotation: Any
   default: Any
   local_dispatchers: List[Union[BaseDispatcher, Callable]]
+  optional: bool
   index: int
 
+  # 即 无论如何都会被激活至少 1 次的 Dispatchers.
+  always_dispatchers: List[Union[BaseDispatcher, Callable]]
+
 class DispatcherInterface:
   broadcast: "Broadcast"
   event: BaseEvent
@@ -35,6 +44,7 @@ class DispatcherInterface:
   # name, annotation, default, local_dispatchers, index
   context_stack: List[ContextStackItem] = [ContextStackItem(None, None, None, [], 0)]
   alive_generater_dispatcher: List[List[Union[Generator, AsyncGenerator]]]
+  always_dispatchers: List[Union[BaseDispatcher, Callable]]
 
   _index = 0
 
@@ -73,6 +83,10 @@ class DispatcherInterface:
     self.event = event_instance
     self.dispatchers = dispatchers
     self.alive_generater_dispatcher = [[]]
+    self.always_dispatchers = []
+    for i in dispatchers:
+      if isinstance(i, BaseDispatcher) and i.always:
+        self.always_dispatchers.append(i)
 
   async def __aenter__(self) -> "DispatcherInterface":
     return self
@@ -93,8 +107,17 @@ class DispatcherInterface:
     
     # create a new context
     # generater has special handle method
-    self.context_stack.append(ContextStackItem(name, annotation, default, []))
+    optional = False
+    if isinstance(annotation, _GenericAlias):
+      if annotation.__origin__ is Union and annotation.__args__[-1] is type(None):
+        # 如果是 Optional, 则它的最后一位应为 NoneType.
+        optional = True
+        annotation = annotation.__args__[0]
+      else:
+        raise TypeError("cannot parse this annotation: {0}".format(annotation))
+    self.context_stack.append(ContextStackItem(name, annotation, default, [], optional=optional))
     self.alive_generater_dispatcher.append([])
+    always_laws = self.always_dispatchers[:]
     try:
       for self.context_stack[-1].index, dispatcher in enumerate(
           self.dispatchers[self._index:], start=self._index):
@@ -102,7 +125,13 @@ class DispatcherInterface:
         # just allow Dispatcher(class or instance) or any Callable
         if not isinstance(dispatcher, BaseDispatcher) and not callable(dispatcher):
             raise InvaildDispatcher("dispatcher must base on 'BaseDispatcher' or is a callable: ", dispatcher)
-          
+        
+        if dispatcher in self.context_stack[-1].always_dispatchers:
+          self.context_stack[-1].always_dispatchers.remove(dispatcher)
+        
+        if dispatcher in always_laws:
+          always_laws.remove(dispatcher)
+
         local_dispatcher = None
         if inspect.isclass(dispatcher) and issubclass(dispatcher, BaseDispatcher):
           local_dispatcher = dispatcher().catch
@@ -141,8 +170,39 @@ class DispatcherInterface:
 
         return result
       else:
+        if optional:
+          return None
         raise RequirementCrashed("the dispatching requirement crashed: ", self.name, self.annotation, self.default)
-    finally:
+    finally: # 在某种程度上, 这算 BCC 内的第二个 "无头充数" 的设计了.
+      for always_dispatcher in [*always_laws, *self.context_stack[-1].always_dispatchers]:
+        local_dispatcher = None
+        if inspect.isclass(always_dispatcher) and issubclass(always_dispatcher, BaseDispatcher):
+          local_dispatcher = always_dispatcher().catch
+        elif callable(always_dispatcher) and not inspect.isclass(always_dispatcher):
+          local_dispatcher = always_dispatcher
+        elif isinstance(always_dispatcher, BaseDispatcher):
+          local_dispatcher = always_dispatcher.catch
+
+        if is_asyncgener(local_dispatcher):
+          now_dispatcher_generater = local_dispatcher(self).__aiter__()
+          try:
+            await now_dispatcher_generater.__anext__()
+          except StopAsyncIteration:
+            pass
+          self.alive_generater_dispatcher[-1].append(now_dispatcher_generater)
+        elif inspect.isgeneratorfunction(local_dispatcher):
+          now_dispatcher_generater = local_dispatcher(self).__iter__()
+          try:
+            now_dispatcher_generater.__next__()
+          except StopIteration as e:
+            pass
+          self.alive_generater_dispatcher[-1].append(now_dispatcher_generater)
+        else:
+          if inspect.iscoroutinefunction(local_dispatcher):
+            await local_dispatcher(self)
+          else:
+            local_dispatcher(self)
+
       self.context_stack.pop()
 
   async def alive_dispatcher_killer(self):
